@@ -10,9 +10,8 @@
    GNU Lesser General Public License for more details.
    
    You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the 
-   Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
-   Boston, MA 02111-1307  USA
+   License along with this library. If not, see
+   <https://www.gnu.org/licenses/>.
    
    You can contact Elliotte Rusty Harold by sending e-mail to
    elharo@ibiblio.org. Please include the word "XOM" in the
@@ -51,7 +50,7 @@ import nu.xom.Text;
 /**
  * <p>
  * Implements XInclude resolution as specified in 
- * <a href="http://www.w3.org/TR/2004/REC-xinclude-20041220/"
+ * <a href="https://www.w3.org/TR/2004/REC-xinclude-20041220/"
  * target="_top"><cite>XML Inclusions (XInclude) Version 
  * 1.0</cite></a>. Fallbacks are supported. 
  * The XPointer <code>element()</code> scheme and 
@@ -62,7 +61,7 @@ import nu.xom.Text;
  * </p>
  * 
  * @author Elliotte Rusty Harold
- * @version 1.3.1
+ * @version 1.3.9
  *
  */
 public class XIncluder {
